<div class="flexslider">
    <ul class="slides">
        {items}
        <li><img alt="{alt}" src="{src}" /></li>
        {/items}
    </ul>
</div>
<script type="text/javascript" charset="utf-8">
    $(window).load(function() {
        $('.flexslider').flexslider();
    });
</script>