<div>
    {add_btn}
</div>
<div>
    <label>{ln_img_size}</label>
</div>
<div class="photolist">
    {photos}
</div>

<div id="alpha_g_dialog" class="modal hide fade" tabindex="-1" role="dialog">
    <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
        <h3 id="myModalLabel">{msg_edit_photo}</h3>
    </div>
    <div class="modal-body">
        <p>Loading…</p>
    </div>
    <div class="modal-footer">
        <button class="btn" data-dismiss="modal" aria-hidden="true">{ln_close}</button>
        <button class="btn btn-primary">{ln_save}</button>
    </div>
</div>

<div id="add_dialog" class="modal hide fade" tabindex="-1" role="dialog">
    <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>
        <h3 id="myModalLabel">{msg_add_photo}</h3>
    </div>

    <div class="modal-body">
        <div id="addForm" class="itemData">
            <fieldset class="">
                <input type="hidden" name="hash" value="{hash}" />
                <input type="hidden" name="user" value="{id_user}" />
                <input type="hidden" name="photogallery" value="{photogallery}" />
                {block_data}
                <legend>{block_name}</legend>
                {lang_data}
                <div class="control-group">
                    <label class="control-label" for="input_{name}_{id_lan}">{lan_name}</label>
                    <div class="controls">
                        <textarea name="{name}[{id_lan}]" id="input_{name}_{id_lan}"></textarea>
                    </div>
                </div>
                {/lang_data}
                {/block_data}
            </fieldset>
        </div>
        <div class="uploadBlock">
            <input type="file" name="file_upload" id="file_upload" />
        </div>
    </div>
</div>