<?php 

$config['photo_path'] = '/assets/uploads/photogallery';

$config['file_type_desc'] = 'Images';
$config['file_types'] = array('jpg', 'jpeg', 'gif', 'png', 'bmp');

$config['photo_width'] = 800;
$config['photo_height'] = 600;

$config['foreign_key'] = 'id_foreign_key';
$config['main_table'] = 'alphagallery_photo';
$config['alphagallery_photo_pkey'] = 'id_alphagallery_photo';
$config['lang_table'] = 'alphagallery_photo_translate';

$config['main_db_data'] = array('id_foreign_key', 'photo', 'name', 'active');
$config['lang_db_data'] = array('name', 'description');

// fields length
$config['main_db_data_length'] = array(
    'photo' => 16,
    'name' => 32
);
$config['lang_db_data_length'] = array(
    'name' => 32,
    'description' => 255
);