<div id="editForm" class="itemData">
    <input type="hidden" name="id_photo" value="{id_photo}"/>
    <fieldset class="form-horizontal">
        {block_data}
        <legend>{block_name}</legend>
        {lang_data}
        <div class="control-group">
            <label class="control-label" for="input_{name}_{id_lan}">{lan_name}</label>
            <div class="controls">
                <textarea name="{name}[{id_lan}]" id="input_{name}_{id_lan}">{value}</textarea>
            </div>
        </div>
        {/lang_data}
        {/block_data}
    </fieldset>
</div>