.photolist{
    padding-top: 15px;
    float: left
}
.photoitem{
    display: block;
    float: left;
    height: 150px;
    margin: 0 10px 10px 0;
    position: relative;
    text-align: center;
    width: 148px;
    border: 1px solid #ddd;
/*    background: url(/assets/uploads/photogallery/39e3c482.jpeg) no-repeat center center;*/
/*    background: url(/assets/uploads/photogallery/59f7e645.png) no-repeat center center;*/
    background-size: 148px auto;
}
.photoitem img{
    max-width: 148px;
    max-height: 148px;
}
.bottom_foto{
    background: rgba(0,0,0,0.59);
    bottom: 0;
    display: none;
    height: 60px;
    left: 0;
    padding: 10px;
    position: absolute;
    text-align: left;
    width: 130px;
}
.bottom_foto a, .bottom_foto label{
    color: #fff;
}
.bottom_foto a:hover{
    color: #55b9ec;
}
.photoitem:hover .bottom_foto{
    display: block
}
.uploadBlock{
    float: right;
    width: 100%;
}
.itemData{
    float: left;
    width: 100%;
}
#file_upload{
    float: left;
    margin-right: 25px;
}
#file_upload-queue{
    float: left;
}